<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Kadu needs to be restarted before changes to the language settings will take effect.</source>
        <translation>Dil ayarlarındaki değişikliklerin etkili olabilmesi için Kadu&apos;yu yeniden başlatmalısınız.</translation>
    </message>
</context>
<context>
    <name>ConfigWizardActions</name>
    <message>
        <source>Start Configuration Wizard</source>
        <translation>Ayarlama Sihirbazını Başlat</translation>
    </message>
</context>
<context>
    <name>ConfigWizardChooseNetworkPage</name>
    <message>
        <source>&lt;h3&gt;Account Setup&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Hesap Kurulumu&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>IM Network</source>
        <translation>IM Ağı</translation>
    </message>
    <message>
        <source>I want to set up existing account for Kadu</source>
        <translation>Varolan Kadu hesabımı ayarlamak istiyorum</translation>
    </message>
    <message>
        <source>I want to create new account for Kadu</source>
        <translation>Yeni Kadu hesabı açmak istiyorum</translation>
    </message>
    <message>
        <source>I don&apos;t want to set up my account for Kadu now</source>
        <translation>Şuan Kadu için hesabımı ayarlamak istemiyorum</translation>
    </message>
    <message>
        <source>&lt;p&gt;Please choose the network for the account that you would like to set up.&lt;/p&gt;&lt;p&gt;You can also create a new account in the wizard if you don&apos;t already have one&lt;/p&gt;</source>
        <translation>&lt;p&gt;Lütfen hesabınızı kurmak için ağ seçiniz.&lt;/p&gt;&lt;p&gt;Eğer hesabınız yoksa yeni bir tane hesap oluşturabilirisiniz&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>ConfigWizardCompletedPage</name>
    <message>
        <source>&lt;h3&gt;Configuration Wizard Completed&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Ayarlama Sihirbazı Tamamlandı&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>Go to Accounts Setting after closing this window</source>
        <translation>Pencereyi kapattıktan sonra Hesap Ayarlarına git</translation>
    </message>
    <message>
        <source>&lt;p&gt;Confirm your wizard setting to start using Kadu.&lt;/p&gt;</source>
        <translation>&lt;p&gt;Kadu&apos;yu kullanmaya başlamak için sihirbaz ayarlarını onaylayın.&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>ConfigWizardProfilePage</name>
    <message>
        <source>&lt;h3&gt;Welcome to Kadu Instant Messenger&lt;/h3&gt;&lt;p&gt;This wizard will help you to configure the basic settings of Kadu.&lt;/p&gt;&lt;p&gt;Please choose a preferred language and create a nickname&lt;/p&gt;</source>
        <translation>&lt;h3&gt;Kadu Anlık Mesajlaşmaya Hoşgeldiniz&lt;/h3&gt;&lt;p&gt;Bu sihirbaz size Kadu&apos;nun ayarlarını basitçe ayarlamanıza yardım eder.&lt;/p&gt;&lt;p&gt;Lütfen tercih ettiğiniz bir dili seçin ve bir takma isim oluşturun&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;h3&gt;Profile setup&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Profil kurulumu&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Dil</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Takma isim</translation>
    </message>
</context>
<context>
    <name>ConfigWizardSetUpAccountPage</name>
    <message>
        <source>&lt;h3&gt;Account Setup&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Hesap Kurulumu&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;Please enter your account data.&lt;/p&gt;&lt;p&gt;Go back if you want to select a different Account Setup option.&lt;/p&gt;</source>
        <translation>&lt;p&gt;Lütfen hesap verinizi girin.&lt;/p&gt;&lt;p&gt;Eğer isterseniz geriye dönüp diğer Hesap Kurulumlarını seçebilirsiniz.&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>ConfigWizardWindow</name>
    <message>
        <source>Kadu Wizard</source>
        <translation>Kadu Sihirbazı</translation>
    </message>
</context>
</TS>